Module async_conn

Module async_conn 

Async split sender/receiver connection. Inspired by hsqlx’s PgWire.Async architecture.

A single TCP connection is shared by many concurrent handler tasks. The writer task coalesces messages from multiple requests into one write(). The reader task parses responses and dispatches them to waiting handlers via FIFO.

Structs

AsyncConn
A shared async connection that multiplexes requests from many tasks.
StreamHeader
Metadata sent at the start of a streaming response.

Enums

PipelineResponse
Response from a pipeline request.
ResponseCollector
How to collect response messages for a request.

Type Aliases

StreamedRow
A single streamed row.