Query cancellation via CancelRequest.
PostgreSQL cancellation works by opening a NEW TCP connection to the server and sending a 16-byte CancelRequest message containing the backend PID and secret key from the original connection’s BackendKeyData.
Structs
- Cancel
Token - A token that can cancel a running query on a specific backend. Cloneable and Send, can be passed to another task or stored for timeout handling.